@@ -12,7 +12,9 @@ class Migration(migrations.Migration):
 
     operations = [
         migrations.RenameField(
-            model_name="event", old_name="completed_at", new_name="created_at",
+            model_name="event",
+            old_name="completed_at",
+            new_name="created_at",
         ),
         migrations.RenameField(
             model_name="event", old_name="resource_id", new_name="onfido_id"
