@@ -11,7 +11,6 @@ from django.utils.timezone import now as tz_now
 from django.utils.translation import gettext_lazy as _
 
 from ..api import get
-from ..compat import JSONField
 from ..signals import on_completion, on_status_change
 from .event import Event
 
@@ -35,7 +34,7 @@ class BaseModel(models.Model):
         blank=True,
         null=True,
     )
-    raw = JSONField(
+    raw = models.JSONField(
         help_text=_("The raw JSON returned from the API."), blank=True, null=True
     )
 
@@ -98,7 +97,7 @@ class BaseQuerySet(models.QuerySet):
         for obj in self:
             try:
                 obj.fetch()
-            except Exception:
+            except Exception:  # noqa: B902
                 logger.exception("Failed to fetch Onfido object: %r", obj)
 
     def pull(self) -> None:
@@ -106,7 +105,7 @@ class BaseQuerySet(models.QuerySet):
         for obj in self:
             try:
                 obj.pull()
-            except Exception:
+            except Exception:  # noqa: B902
                 logger.exception("Failed to pull Onfido object: %r", obj)
 
 
@@ -229,7 +228,7 @@ class BaseStatusModel(BaseModel):
         self.updated_at = event.completed_at
         try:
             self.pull()
-        except Exception:
+        except Exception:  # noqa: B902
             # even if we can't get latest, we should save the changes we
             # have already made to the object
             logger.warning("Unable to pull latest from Onfido: '%r'", self)
